@@ -137,6 +137,18 @@ class PageFactory(object):
             list_item.append(item.text)
         return list_item
 
+    def verify_list_item(self, text):
+        """
+        Verify text to be present in  Dropdown
+        :param: item to be verify
+        :return: True / False
+        """
+        select = Select(self)
+        for item in select.options:
+            if text == item.text:
+                return True
+        return False
+
     def click_button(self):
         """
         Perform  click on webElement
@@ -312,3 +324,4 @@ WebElement.get_list_selected_item = PageFactory.get_list_selected_item
 WebElement.execute_script = PageFactory.execute_script
 WebElement.text_to_be_present_in_element = PageFactory.text_to_be_present_in_element
 WebElement.element_located_selection_state_to_be = PageFactory.element_located_selection_state_to_be
+WebElement.verify_list_item = PageFactory.verify_list_item
